Coverage report

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/hatch_ci/__init__.py | 2 | 0 | 0 | 0 | 0 | 100%
src/hatch_ci/cli.py | 72 | 72 | 0 | 18 | 0 | 0%
src/hatch_ci/common.py | 1 | 1 | 0 | 0 | 0 | 0%
src/hatch_ci/hooks.py | 5 | 5 | 0 | 0 | 0 | 0%
src/hatch_ci/scm.py | 162 | 27 | 0 | 52 | 8 | 82%
src/hatch_ci/script.py | 67 | 67 | 2 | 20 | 0 | 0%
src/hatch_ci/tools.py | 198 | 11 | 0 | 82 | 9 | 91%
src/hatch_ci/version_hook.py | 17 | 17 | 0 | 2 | 0 | 0%
Total | 524 | 200 | 2 | 174 | 17 | 62%

No items found using the specified filter.